@@ -77,6 +77,7 @@ types: list[str] = [
     "AWS::ApplicationAutoScaling::ScalingPolicy",
     "AWS::ApplicationInsights::Application",
     "AWS::ApplicationSignals::Discovery",
+    "AWS::ApplicationSignals::GroupingConfiguration",
     "AWS::ApplicationSignals::ServiceLevelObjective",
     "AWS::Athena::DataCatalog",
     "AWS::Athena::NamedQuery",
@@ -102,6 +103,8 @@ types: list[str] = [
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
     "AWS::Batch::ServiceEnvironment",
+    "AWS::Bedrock::Guardrail",
+    "AWS::Bedrock::GuardrailVersion",
     "AWS::CDK::Metadata",
     "AWS::CE::AnomalyMonitor",
     "AWS::CE::AnomalySubscription",
@@ -160,6 +163,7 @@ types: list[str] = [
     "AWS::CodeDeploy::DeploymentGroup",
     "AWS::CodePipeline::CustomActionType",
     "AWS::CodePipeline::Pipeline",
+    "AWS::CodePipeline::Webhook",
     "AWS::Cognito::IdentityPool",
     "AWS::Cognito::IdentityPoolPrincipalTag",
     "AWS::Cognito::IdentityPoolRoleAttachment",
@@ -438,6 +442,9 @@ types: list[str] = [
     "AWS::KMS::Alias",
     "AWS::KMS::Key",
     "AWS::KMS::ReplicaKey",
+    "AWS::KafkaConnect::Connector",
+    "AWS::KafkaConnect::CustomPlugin",
+    "AWS::KafkaConnect::WorkerConfiguration",
     "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
@@ -810,6 +817,7 @@ cached: list[str] = [
     "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationinsights-application.json",
     "aws-applicationsignals-discovery.json",
+    "aws-applicationsignals-groupingconfiguration.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appsync-api.json",
     "aws-appsync-apicache.json",
@@ -825,7 +833,6 @@ cached: list[str] = [
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-scraper.json",
     "aws-aps-workspace.json",
-    "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
@@ -852,6 +859,8 @@ cached: list[str] = [
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
+    "aws-bedrock-guardrail.json",
+    "aws-bedrock-guardrailversion.json",
     "aws-ce-anomalymonitor.json",
     "aws-ce-anomalysubscription.json",
     "aws-certificatemanager-certificate.json",
@@ -907,6 +916,7 @@ cached: list[str] = [
     "aws-codedeploy-deploymentgroup.json",
     "aws-codepipeline-customactiontype.json",
     "aws-codepipeline-pipeline.json",
+    "aws-codepipeline-webhook.json",
     "aws-cognito-identitypool.json",
     "aws-cognito-identitypoolprincipaltag.json",
     "aws-cognito-identitypoolroleattachment.json",
@@ -1162,6 +1172,9 @@ cached: list[str] = [
     "aws-inspectorv2-filter.json",
     "aws-internetmonitor-monitor.json",
     "aws-iot-thingprincipalattachment.json",
+    "aws-kafkaconnect-connector.json",
+    "aws-kafkaconnect-customplugin.json",
+    "aws-kafkaconnect-workerconfiguration.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
@@ -1186,16 +1199,13 @@ cached: list[str] = [
     "aws-launchwizard-deployment.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
-    "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
     "aws-logs-loganomalydetector.json",
     "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
-    "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
-    "aws-logs-subscriptionfilter.json",
     "aws-logs-transformer.json",
     "aws-mediaconnect-flow.json",
     "aws-mediaconnect-flowentitlement.json",
@@ -1236,6 +1246,7 @@ cached: list[str] = [
     "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
+    "aws-neptune-eventsubscription.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
     "aws-networkfirewall-loggingconfiguration.json",
@@ -1318,10 +1329,13 @@ cached: list[str] = [
     "aws-route53resolver-firewalldomainlist.json",
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
+    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-route53resolver-resolverrule.json",
+    "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
@@ -1362,6 +1376,8 @@ cached: list[str] = [
     "aws-servicecatalog-launchnotificationconstraint.json",
     "aws-servicecatalog-launchroleconstraint.json",
     "aws-servicecatalog-launchtemplateconstraint.json",
+    "aws-servicecatalog-portfolioprincipalassociation.json",
+    "aws-servicecatalog-portfolioproductassociation.json",
     "aws-servicecatalog-portfolioshare.json",
     "aws-servicecatalog-resourceupdateconstraint.json",
     "aws-servicecatalog-serviceaction.json",
@@ -1427,8 +1443,10 @@ cached: list[str] = [
     "aws-verifiedpermissions-policy.json",
     "aws-verifiedpermissions-policystore.json",
     "aws-verifiedpermissions-policytemplate.json",
+    "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
     "aws-vpclattice-listener.json",
+    "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
     "aws-vpclattice-servicenetwork.json",
